HeadingAnchorsExtension class

An extension that generates anchor links for headers in the page.

The resulting anchor links are appended to the headers as a clickable '#' symbol.

Implemented types

Constructors

HeadingAnchorsExtension({int maxHeaderDepth = 3})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxHeaderDepth → int
The maximum header depth to generate anchors for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Page page, List<Node> nodes) → Future<List<Node>>
Applies the extension to the given Page and parsed Nodes.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited